package
Version:
v0.0.0-...-180210d
Opens a new window with list of versions in this module.
Published: Jul 14, 2025
License: AGPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
var DbConfig = &mainDB{
DbPtr: nil,
Host: "localhost",
Port: 8000,
Prefix: "ws://",
User: "ezy",
Pass: "1234",
NS: "dev",
Database: "ezMsg",
}
func InitDB() (*mainDB, string)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.